/////////////////////////////////////////////////////////////////////////////
// Name:        Wx.rc
// Purpose:     wxPerl resource file
// Author:      Mattia Barbon
// Modified by:
// Created:     29/10/2000
// RCS-ID:      $Id: Wx.rc,v 1.7 2004/12/21 21:12:19 mbarbon Exp $
// Copyright:   (c) 2000-2002, 2004 Mattia Barbon
// Licence:     This program is free software; you can redistribute it and/or
//              modify it under the same terms as Perl itself
/////////////////////////////////////////////////////////////////////////////

#include <wx/version.h>

wxplicon ICON "wxpl.ico"

#include <wx/msw/wx.rc>
